@@ -29,14 +29,19 @@ def format_parameters(params):
     return parameters
 
 
-def monascaclient(request, password=None):
-    api_version = "2_0"
-    insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
-    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+def monasca_endpoint(request):
     service_type = getattr(settings, 'MONITORING_SERVICE_TYPE', 'monitoring')
     endpoint = base.url_for(request, service_type)
     if endpoint.endswith('/'):
         endpoint = endpoint[:-1]
+    return endpoint
+
+
+def monascaclient(request, password=None):
+    api_version = "2_0"
+    insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
+    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+    endpoint = monasca_endpoint(request)
     LOG.debug('monascaclient connection created using token "%s" , url "%s"' %
               (request.user.token.id, endpoint))
     kwargs = {
